@@ -26,6 +26,7 @@ from sleuthpr.services import rules
 from sleuthpr.services.scm import Commit
 from sleuthpr.triggers import PR_CLOSED
 from sleuthpr.triggers import PR_CREATED
+from sleuthpr.triggers import PR_REOPENED
 from sleuthpr.triggers import PR_UPDATED
 from sleuthpr.util import dirty_set_all
 
@@ -64,7 +65,8 @@ def on_check_run(installation: Installation, repository: Repository, data: Dict)
 
 def on_push(installation: Installation, repository: Repository, data: Dict):
     pull_requests.add_commits(
-        repository, [Commit(sha=c.get("id", c.get("sha")), message=c["message"], parents=[]) for c in data["commits"]]
+        repository,
+        [commit_data_to_commit(c) for c in data["commits"]],
     )
     if "refs/heads/master" == data["ref"]:
         files = {}
@@ -99,8 +101,11 @@ def on_pr_updated(installation: Installation, repository: Repository, pr_data: D
 
 
 def on_pr_closed(installation: Installation, repository: Repository, pr_data: Dict):
-    pr = _update_pull_request_and_process(installation, repository, pr_data, event=PR_CLOSED)
-    pull_requests.delete(repository, pr)
+    _update_pull_request_and_process(installation, repository, pr_data, event=PR_CLOSED)
+
+
+def on_pr_reopened(installation: Installation, repository: Repository, pr_data: Dict):
+    _update_pull_request_and_process(installation, repository, pr_data, event=PR_REOPENED)
 
 
 def on_repositories_added(installation: Installation, data):
@@ -140,6 +145,18 @@ def on_installation_created(remote_id: str, data):
     )
 
 
+def commit_data_to_commit(c) -> Commit:
+    return Commit(
+        sha=c.get("id", c.get("sha")),
+        message=c.get("message"),
+        parents=[p["sha"] for p in c.get("parents", [])],
+        author_name=c["author"].get("name", c["author"].get("login")),
+        author_email=c["author"].get("email"),
+        committer_name=c["committer"].get("name", c["author"].get("login")),
+        committer_email=c["committer"].get("email"),
+    )
+
+
 def _update_pull_request_and_process(
     installation: Installation, repository: Repository, data: Dict, event=PR_UPDATED
 ):
@@ -218,8 +235,11 @@ def _update_pr_details(data, installation, pr):
             author=_get_user(installation, data["user"]),
             draft=data["draft"],
             merged=data.get("merged", False),
-            mergeable=TriState.from_bool(data.get("mergeable")),
-            rebaseable=TriState.from_bool(data.get("rebaseable")),
+            conflict=TriState.UNKNOWN.value
+            if not data.get("mergeable_state")
+            else TriState.from_bool(data.get("mergeable_state") == "dirty").value,
+            mergeable=TriState.from_bool(data.get("mergeable")).value,
+            rebaseable=TriState.from_bool(data.get("rebaseable")).value,
         ),
     )
 
